package com.zzyd.request;

import com.zzyd.request.base.IBaseRequest;
import com.zzyd.response.RefundResponse;
import lombok.Data;
import java.util.List;
import java.util.Map;

/**
 * @Description: 请求参数对象，用于退款请求。
 */
@Data
public class RefundRequest implements IBaseRequest<RefundRequest, RefundResponse> {

    /**
     * @Description: 收钱吧终端ID
     */
    private String terminal_sn;

    /**
     * @Description: 收钱吧唯一订单号
     */
    private String sn;

    /**
     * @Description: 商户订单号
     */
    private String client_sn;

    /**
     * @Description: 退款序列号
     */
    private String refund_request_no;

    /**
     * @Description: 操作员
     */
    private String operator;

    /**
     * @Description: 退款金额
     */
    private String refund_amount;

    /**
     * @Description: 扩展参数集合
     */
    private Map<String, String> extended;

    /**
     * @Description: 商品详情，格式为数组，元素为json对象
     */
    private List<GoodsDetail> goods_details;

    /**
     * @Description: 反射参数
     */
    private String reflect;

    /**
     * @Description: 方法路径后缀
     * @return 请求路径的后缀
     */
    @Override
    public String apiPathSuffix() {
        return "/upay/v2/refund";
    }

    /**
     * @Description: 返回值是否为集合
     * @return 如果返回值是集合，返回true；否则返回false
     */
    @Override
    public boolean ifList() {
        return false;
    }

    @Data
    public static class GoodsDetail {
        /**
         * @Description: 商品的编号
         */
        private String goods_id;

        /**
         * @Description: 商品名称
         */
        private String goods_name;

        /**
         * @Description: 商品退款金额
         */
        private String refund_amount;

        /**
         * @Description: 商品数量
         */
        private Integer quantity;

        /**
         * @Description: 商品单价
         */
        private String price;

        /**
         * @Description: 优惠类型
         */
        private Integer promotion_type;
    }
}
