package com.zzyd.response;

import lombok.Data;
import java.util.List;

/**
 * @Description: 回调接口参数对象，用于支付成功或失败订单信息推送。
 */
@Data
public class PaymentCallbackResponse {

    /**
     * @Description: 收钱吧唯一订单号
     */
    private String sn;

    /**
     * @Description: 商户订单号
     */
    private String clientSn;

    /**
     * @Description: 支付服务商订单号，只有支付成功时才有值返回
     */
    private String tradeNo;

    /**
     * @Description: 流水状态
     */
    private String status;

    /**
     * @Description: 订单状态
     */
    private String orderStatus;

    /**
     * @Description: 支付方式，一级支付方式
     */
    private String payway;

    /**
     * @Description: 二级支付方式
     */
    private String subPayway;

    /**
     * @Description: 付款人ID，支付平台（微信，支付宝）上的付款人ID
     */
    private String payerUid;

    /**
     * @Description: 付款人账号，支付平台上(微信，支付宝)的付款人账号
     */
    private String payerLogin;

    /**
     * @Description: 交易总额
     */
    private String totalAmount;

    /**
     * @Description: 实收金额，如果没有退款，这个字段等于totalAmount。否则等于 totalAmount减去退款金额
     */
    private String netAmount;

    /**
     * @Description: 本次操作金额，本次支付金额
     */
    private String settlementAmount;

    /**
     * @Description: 交易概述
     */
    private String subject;

    /**
     * @Description: 付款动作在收钱吧的完成时间，时间戳
     */
    private String finishTime;

    /**
     * @Description: 付款动作在支付服务商的完成时间，时间戳，只有支付成功时才有值返回
     */
    private String channelFinishTime;

    /**
     * @Description: 操作员，门店操作员
     */
    private String operator;

    /**
     * @Description: 反射参数，透传参数
     */
    private String reflect;

    /**
     * @Description: 优惠详情，格式为json，内容有两部分 goodsDetails为数组，内容为核销单品信息，voucherDetails为数组，内容为核销券信息
     */
    private String providerResponse;

    /**
     * @Description: 活动优惠，订单内活动优惠信息概览，格式为数组，元素为json对象
     */
    private List<Payment> paymentList;

    @Data
    public static class Payment {

        /**
         * @Description: 活动类型
         */
        private String type;

        /**
         * @Description: 活动出资总金额
         */
        private String amountTotal;
    }
}
